@@ -3,6 +3,7 @@
  * @tags: [
  *    # TODO (SERVER-97257): Re-enable this test or add an explanation why it is incompatible.
  *    embedded_router_incompatible,
+ *    requires_fcv_70,
  *    grpc_incompatible,
  * ]
  */
@@ -21,6 +22,3 @@ testProxyProtocolShardedCluster(ingressPort, egressPort, 2, emptyMessageTest);
 
 testProxyProtocolShardedCluster(ingressPort, egressPort, 1, fuzzingTest);
 testProxyProtocolShardedCluster(ingressPort, egressPort, 2, fuzzingTest);
-
-testProxyProtocolShardedCluster(ingressPort, egressPort, 1, loadTest);
-testProxyProtocolShardedCluster(ingressPort, egressPort, 2, loadTest);
